@@ -2,6 +2,7 @@
 import os
 
 import click
+from prettytable import PrettyTable
 
 from src.cmd import cmd_manager
 from src.config import global_config, config_manager
@@ -44,7 +45,7 @@ def print_version(ctx, param, value):
     bash:在.bashrc末尾添加 eval "$(_M_COMPLETE=source m)"
     zsh:在.zshrc末尾添加 eval "$(_M_COMPLETE=source_zsh m)"
     依赖的工具：{}
-    jiuming-tools Version {}""".format(tools_lib_str, global_config.getVersion())
+    jiuming-tools Version {}""".format(tools_lib_str, global_config.get_version())
     click.echo(version_info)
     ctx.exit()
 
@@ -75,43 +76,22 @@ def check_tools_dependency(ctx, param, value):
             for f in os.listdir(bin_path):
                 cmd_name_set.add(f)
     # 获取系统依赖工具列表
-    no_install_tools_name = []
-    echo_str = "检查依赖。。。。\n"
+    t_table = PrettyTable(['name', "desc", 'result', 'remark'])
+    # 设置对齐方式
+    t_table.align = "l"
+    # 设置表格最长列
+    t_table.max_width = 80
     for i in tools_dependency_info_arr:
-        echo_str += "开始检测:{}\n备注:{}\n".format(i.cmd, i.desc)
-        if i.cmd in cmd_name_set:
-            echo_str += "{}已经安装!\n".format(i.cmd)
-        else:
-            echo_str += "{}未安装!安装示例:{}\n".format(i.cmd, i.install_demo_cmd)
-            no_install_tools_name.append(i.cmd)
-        echo_str += "--------------------------------------\n"
-    echo_str += "依赖检查完毕!\n"
-    click.echo(echo_str)
-    if len(no_install_tools_name) > 0:
-        click.echo(click.style("{}未安装!部分功能无法正常运行!\n".format(no_install_tools_name), fg='red'))
+        t_table.add_row([i.cmd, i.desc, cmd_name_set.__contains__(i.cmd), i.install_demo_cmd])
+    click.echo(t_table)
     ctx.exit()
 
 
-def init_tools(ctx, param, value):
-    # 判断当前shell 根据不同shell 追加内容
-    # bash  在~/.bashrc 追加  eval "$(_M_COMPLETE=source m)"
-
-    # zsh 在~/.zshrc 追加内容  eval "$(_M_COMPLETE=source_zsh m)"
-
-    # 添加脚本目录到PATH下
-    # todo ming ？ 是否做软链接建立脚本别名?
-
-    pass
-
-
 @click.group()
 @click.option('--version', '-v', help='工具版本', is_flag=True, callback=print_version, expose_value=False, is_eager=True)
 @click.option('--check', '-c', help='检测当前环境下工具依赖是否完整', is_flag=True, callback=check_tools_dependency,
               expose_value=False,
               is_eager=True)
-@click.option('--init', '-i', help='初始化项目(命令提示、添加shell脚本目录到PATH中)', is_flag=True, callback=init_tools,
-              expose_value=False,
-              is_eager=True)
 def cli():
     pass
 
@@ -257,6 +237,12 @@ def mem_info(top, pid, details):
     pc_info.mem_info(top, pid, details)
 
 
+@local.command('net-info', help='获取网络信息,需要root权限')
+@click.option('--details', '-d', type=click.BOOL, default=False, help='显示详情')
+def net_info(details):
+    pass
+
+
 # @local.command('detect', help='侦测当前设备各项资源')
 # def detect():
 #     pc_info.detect()
